##  Overview
Before an ERP transformation is initiated with the discovery phase, there is a preliminary “Phase zero.” This phase concludes with a formal decision to start the migration and plan respective budgets. The artifacts produced during this phase include:
  * A discussion and documentation of the transformation's goals and its business case (for example, high-level benefits vs. costs).
  * A decision or at least a strong hypothesis on the transformation approach (typically, three different approaches are discussed: [Greenfield-, Brownfield, or Hybrid Approach![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fwiki%2Fea%2Fs4hana-greenfield-vs-brownfield-approach "https://www.leanix.net/en/wiki/ea/s4hana-greenfield-vs-brownfield-approach")).
  * The setup of the transformation program to be initiated, for example, program organization, involvement of external consultants, and identification of business units to be involved.


It is important to understand that during this phase -- even though the details will only be worked out in subsequent phases -- information on the current solution, the benefits of moving to a new ERP solution, the capabilities of the organization, and details about data and interface availability is required for informed discussions and sound decision-making. Typically, Integration Architecture is a key aspect of identifying the right migration approach.
Often, external consultants are involved in this phase. While they might have a good external perspective, they might lack knowledge of your specific situation. As an Enterprise Architect, you should ensure that you are involved and contribute in this phase. Spread awareness of the critical role of EA and good transparency of the as-is architecture for a successful day 1 without any surprises. To give one example: Imagine that your organization decides to change the length of the personal ID number in the HR system from 5 to 8. You need to know exactly which systems are connected and need to be adjusted. Otherwise, data flow and processes might be blocked, which can have serious consequences (for example, payroll).
Ideally, your organization can use SAP LeanIX already in this phase for a good pre-study and informed decision-making. At least, you as an EA should ensure the active participation of the Enterprise Architect team by clearly defining its role in the ERP transformation.
